@@ -294,6 +294,7 @@ class Page(ElasticEntity):
         'order': int,
         'overview': str,
         'content': str,
+        'custom_text': str,
         'has_toc': bool,
         'attachs': list,
         'software': list,
@@ -343,6 +344,7 @@ class Page(ElasticEntity):
         'establishedon': DateTimeField,
         'affiliate': str,
         'affiliate_contact': str,
+        'affiliate_email': str,
         'affiliate_ref': str,
         'website': str,
         'ref_link_geo': list,
@@ -371,6 +373,7 @@ class Page(ElasticEntity):
         'min_deposit': int,
         'min_withdrawal': int,
         'cashiers_limits': list,
+        'games_limits': list,
         'withdrawal_time': list,
         'withdrawal_limits': list,
         'withdrawal_monthly': int,
@@ -385,7 +388,6 @@ class Page(ElasticEntity):
         'wager_type': str,
         'welcome_package_fs': int,
         'welcome_package_min_dep': int,
-        'cashback': int,
         'no_deposit_fs': int,
         'no_deposit_note': str,
         'promotions': list,
@@ -409,6 +411,7 @@ class Page(ElasticEntity):
         'collection_cpp': int,
         'collection_sort': str,
         'collection_sort_direction': str,
+        'collection_column_title': str
     }
 
     @classmethod
@@ -642,6 +645,7 @@ class Page(ElasticEntity):
             'apps': ['google_play', 'app_store'],
             'times': ['ewallets', 'cards', 'bank', 'cryptocurrency'],
             'limits': ['transaction', 'day', 'week', 'month'],
+            'game_types': ['slots', 'roulette', 'blackjack'],
             'locale': [],
             'bgcolor': [],
             'collection_mode': [], # 'Best', 'New', 'Software'
@@ -683,7 +687,7 @@ class Page(ElasticEntity):
         return None
 
     @classmethod
-    def query(cls, query, is_full=False):
+    def query(cls, query, is_full=False, locale='en', category=[], in_locale=None, count=10):
         if not query:
             return []
 
@@ -706,15 +710,21 @@ class Page(ElasticEntity):
                 {"term": {"is_redirect": False}},
                 {"term": {"is_draft": False}},
                 {"term": {"is_sandbox": False}},
-                {"term": {"locale.keyword": 'en'}},
             ]
+            if locale:
+                must.append({"term": {"locale.keyword": locale}})
+            if category:
+                must.append({"terms": {"category.keyword": category}})
+            if in_locale:
+                must.append({"term": {"locale_available.keyword": in_locale}})
 
         q = {
             "query": {
                 "bool": {
                     "must": must
                 }
-            }
+            },
+            "size": count
         }
 
         resp = current_app.es.search(index=cls._table(), body=q, request_timeout=60, ignore=[404])
@@ -779,7 +789,7 @@ class Page(ElasticEntity):
         if country:
             filter_list.append({"term": {"geo.keyword": country}})            
         for key, value in params.items():
-            if key not in ['sorting', 'cpp', 'query']:
+            if key not in ['sorting', 'cpp', 'query', 'is_grid', 'is_geo']:
                 if isinstance(value, bool):
                     filter_list.append({"term": {key: value}})
                 elif isinstance(value, list):
